@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,12 +30,13 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <vector>
 
 bool CommandFactory::register_command(const std::string& name, const std::string& description, create_command_type&& create_function) {
-    command_info info{description, std::forward<create_command_type>(create_function)};
+    const command_info info{description, std::forward<create_command_type>(create_function)};
     return m_commands.emplace(name, info).second;
 }
 
 std::vector<std::pair<std::string, std::string>> CommandFactory::help() const {
     std::vector<std::pair<std::string, std::string>> commands;
+    commands.reserve(m_commands.size());
 
     for (const auto& cmd : m_commands) {
         commands.emplace_back(cmd.first, cmd.second.description);
