@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,6 +25,10 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include "cmd.hpp" // IWYU pragma: export
 
+#include <osmium/io/reader.hpp>
+#include <osmium/io/writer.hpp>
+#include <osmium/object_pointer_collection.hpp>
+
 #include <string>
 #include <vector>
 
@@ -38,6 +42,11 @@ class CommandApplyChanges : public CommandWithSingleOSMInput, public with_osm_ou
     bool m_locations_on_ways = false;
     bool m_redact = false;
 
+    void apply_changes_and_write(osmium::ObjectPointerCollection &objects,
+                                 const std::vector<osmium::memory::Buffer> &changes,
+                                 osmium::io::Reader &reader,
+                                 osmium::io::Writer &writer);
+
 public:
 
     explicit CommandApplyChanges(const CommandFactory& command_factory) :
