@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -255,7 +255,7 @@ void CommandExport::canonicalize_output_format() {
 }
 
 bool CommandExport::setup(const std::vector<std::string>& arguments) {
-    std::string default_index_type{"flex_mem"};
+    const std::string default_index_type{"flex_mem"};
 
     po::options_description opts_cmd{"COMMAND OPTIONS"};
     opts_cmd.add_options()
@@ -274,11 +274,10 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
     ("stop-on-error,E", "Stop on the first error encountered")
     ("show-index-types,I", "Show available index types")
     ("attributes,a", po::value<std::string>(), "Comma-separated list of attributes to add to the output (default: none)")
-    ("omit-rs,r", "Do not print RS (record separator) character when using JSON Text Sequences")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -459,14 +458,6 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
         }
     }
 
-    if (vm.count("omit-rs")) {
-        m_options.format_options.set("print_record_separator", false);
-        warning("The --omit-rs/-r option is deprecated. Please use '-x print_record_separator=false' instead.\n");
-        if (m_output_format != "geojsonseq") {
-            warning("The --omit-rs/-r option only works for GeoJSON Text Sequence (geojsonseq) format. Ignored.\n");
-        }
-    }
-
     if (vm.count("show-errors")) {
         m_show_errors = true;
     }
@@ -606,7 +597,7 @@ bool CommandExport::run() {
         handler->debug_output(m_vout, m_output_filename);
     }
 
-    osmium::area::Assembler::config_type assembler_config;
+    const osmium::area::Assembler::config_type assembler_config;
     osmium::area::MultipolygonManager<osmium::area::Assembler> mp_manager{assembler_config};
 
     m_vout << "First pass (of two) through input file (reading relations)...\n";
