@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 # include <io.h>
 #endif
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 # include <unistd.h>
 #endif
 
@@ -165,6 +165,19 @@ static osmium::Box parse_bbox(const rapidjson::Value& value) {
     throw config_error{"'bbox' member is not an array or object."};
 }
 
+#ifdef _WIN32
+static bool is_valid_driver_char(const char value) noexcept {
+    return ((value | 0x20) - 'a') <= ('z' - 'a');
+}
+
+static bool is_path_rooted(const std::string& path) noexcept {
+    const std::size_t len = path.size();
+
+    return (len >= 1 && (path[0] == '\\' || path[0] == '/'))
+        || (len >= 2 && is_valid_driver_char(path[0]) && path[1] == ':');
+}
+#endif
+
 static std::size_t parse_multipolygon_object(const std::string& directory, std::string file_name, std::string file_type, osmium::memory::Buffer* buffer) {
     assert(buffer);
 
@@ -172,7 +185,13 @@ static std::size_t parse_multipolygon_object(const std::string& directory, std::
         throw config_error{"Missing 'file_name' in '(multi)polygon' object."};
     }
 
-    if (file_name[0] != '/') {
+#ifdef _WIN32
+    const bool is_relative = !is_path_rooted(file_name);
+#else
+    const bool is_relative = file_name[0] != '/';
+#endif
+
+    if (is_relative) {
         // relative file name
         file_name = directory + file_name;
     }
@@ -185,8 +204,8 @@ static std::size_t parse_multipolygon_object(const std::string& directory, std::
         } else if (ends_with(file_name, ".json") || ends_with(file_name, ".geojson")) {
             file_type = "geojson";
         } else {
-            std::string suffix{get_filename_suffix(file_name)};
-            osmium::io::File osmfile{"", suffix};
+            const std::string suffix{get_filename_suffix(file_name)};
+            const osmium::io::File osmfile{"", suffix};
             if (osmfile.format() != osmium::io::file_format::unknown) {
                 file_type = "osm";
             }
@@ -303,7 +322,7 @@ void CommandExtract::parse_config_file() {
         throw config_error{"Top-level value must be an object."};
     }
 
-    std::string directory{get_value_as_string(doc, "directory")};
+    const std::string directory{get_value_as_string(doc, "directory")};
     if (!directory.empty() && m_output_directory.empty()) {
         m_vout << "  Directory set to '" << directory << "'.\n";
         set_directory(directory);
@@ -320,26 +339,26 @@ void CommandExtract::parse_config_file() {
 
     m_vout << "  Reading extracts from config file...\n";
     int extract_num = 1;
-    for (const auto& e : json_extracts->value.GetArray()) {
+    for (const auto& item : json_extracts->value.GetArray()) {
         std::string output;
         try {
-            if (!e.IsObject()) {
+            if (!item.IsObject()) {
                 throw config_error{"Members in 'extracts' array must be objects."};
             }
 
-            output = get_value_as_string(e, "output");
+            output = get_value_as_string(item, "output");
             if (output.empty()) {
                 throw config_error{"Missing 'output' field for extract."};
             }
 
             m_vout << "    Looking at extract '" << output << "'...\n";
 
-            std::string output_format{get_value_as_string(e, "output_format")};
-            std::string description{get_value_as_string(e, "description")};
+            const std::string output_format{get_value_as_string(item, "output_format")};
+            const std::string description{get_value_as_string(item, "description")};
 
-            const auto json_bbox         = e.FindMember("bbox");
-            const auto json_polygon      = e.FindMember("polygon");
-            const auto json_multipolygon = e.FindMember("multipolygon");
+            const auto json_bbox         = item.FindMember("bbox");
+            const auto json_polygon      = item.FindMember("polygon");
+            const auto json_multipolygon = item.FindMember("multipolygon");
 
             osmium::io::File output_file{m_output_directory + output, output_format};
             if (m_with_history) {
@@ -348,23 +367,23 @@ void CommandExtract::parse_config_file() {
                 throw config_error{"Looks like you are trying to write a history file, but option --with-history is not set."};
             }
 
-            if (json_bbox != e.MemberEnd()) {
+            if (json_bbox != item.MemberEnd()) {
                 m_extracts.push_back(std::make_unique<ExtractBBox>(output_file, description, parse_bbox(json_bbox->value)));
-            } else if (json_polygon != e.MemberEnd()) {
+            } else if (json_polygon != item.MemberEnd()) {
                 m_extracts.push_back(std::make_unique<ExtractPolygon>(output_file, description, m_buffer, parse_polygon(m_config_directory, json_polygon->value, &m_buffer)));
-            } else if (json_multipolygon != e.MemberEnd()) {
+            } else if (json_multipolygon != item.MemberEnd()) {
                 m_extracts.push_back(std::make_unique<ExtractPolygon>(output_file, description, m_buffer, parse_multipolygon(m_config_directory, json_multipolygon->value, &m_buffer)));
             } else {
                 throw config_error{"Missing geometry for extract. Need 'bbox', 'polygon', or 'multipolygon'."};
             }
 
-            Extract& extract = *m_extracts.back();
-            const auto json_output_header = e.FindMember("output_header");
-            if (json_output_header != e.MemberEnd()) {
+            const auto json_output_header = item.FindMember("output_header");
+            if (json_output_header != item.MemberEnd()) {
                 const auto& value = json_output_header->value;
                 if (!value.IsObject()) {
                     throw config_error{"Optional 'output_header' field must be an object."};
                 }
+                Extract& extract = *m_extracts.back();
                 for (auto it = value.MemberBegin(); it != value.MemberEnd(); ++it) {
                     const auto& member_value = it->value;
                     if (member_value.IsNull()) {
@@ -444,9 +463,9 @@ bool CommandExtract::setup(const std::vector<std::string>& arguments) {
     ("clean", po::value<std::vector<std::string>>(), "Clean attribute (version, changeset, timestamp, uid, user)")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
