@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <utility>
 #include <vector>
 
-#ifndef _MSC_VER
+#ifndef _WIN32
 # include <unistd.h>
 #endif
 
@@ -348,7 +348,7 @@ public:
 
         if (!input_file.filename().empty()) {
             m_writer.String("size");
-            m_writer.Int64(file_size(input_file));
+            m_writer.Int64(static_cast<int64_t>(file_size(input_file)));
         }
 
         m_writer.EndObject();
@@ -427,13 +427,13 @@ public:
         m_writer.String("count");
         m_writer.StartObject();
         m_writer.String("changesets");
-        m_writer.Int64(info_handler.changesets);
+        m_writer.Int64(static_cast<int64_t>(info_handler.changesets));
         m_writer.String("nodes");
-        m_writer.Int64(info_handler.nodes);
+        m_writer.Int64(static_cast<int64_t>(info_handler.nodes));
         m_writer.String("ways");
-        m_writer.Int64(info_handler.ways);
+        m_writer.Int64(static_cast<int64_t>(info_handler.ways));
         m_writer.String("relations");
-        m_writer.Int64(info_handler.relations);
+        m_writer.Int64(static_cast<int64_t>(info_handler.relations));
         m_writer.EndObject();
 
         m_writer.String("minid");
@@ -463,11 +463,11 @@ public:
         m_writer.String("buffers");
         m_writer.StartObject();
         m_writer.String("count");
-        m_writer.Int64(get_largest(info_handler.buffers_count));
+        m_writer.Int64(get_largest(static_cast<int64_t>(info_handler.buffers_count)));
         m_writer.String("size");
-        m_writer.Int64(get_largest(info_handler.buffers_size));
+        m_writer.Int64(get_largest(static_cast<int64_t>(info_handler.buffers_size)));
         m_writer.String("capacity");
-        m_writer.Int64(get_largest(info_handler.buffers_capacity));
+        m_writer.Int64(get_largest(static_cast<int64_t>(info_handler.buffers_capacity)));
         m_writer.EndObject();
 
         m_writer.String("metadata");
@@ -730,8 +730,8 @@ bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
     ("object-type,t", po::value<std::vector<std::string>>(), "Read only objects of given type (node, way, relation, changeset)")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -871,7 +871,7 @@ bool CommandFileinfo::run() {
     output->file(m_input_filename, m_input_file);
 
     osmium::io::Reader reader{m_input_file, m_extended ? osm_entity_bits() : osmium::osm_entity_bits::nothing};
-    osmium::io::Header header{reader.header()};
+    const osmium::io::Header header{reader.header()};
     output->header(header);
 
     if (m_extended) {
