@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -53,9 +53,9 @@ bool CommandMerge::setup(const std::vector<std::string>& arguments) {
     ("with-history,H", "Do not warn about input files with multiple object versions")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_multiple_inputs_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_multiple_inputs_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -258,9 +258,9 @@ bool CommandMerge::run() {
                 writer(element.object());
             }
 
-            const int index = element.data_source_index();
-            if (data_sources[index].next()) {
-                queue.emplace(data_sources[index].get(), index);
+            const int dsindex = element.data_source_index();
+            if (data_sources[dsindex].next()) {
+                queue.emplace(data_sources[dsindex].get(), dsindex);
             }
 
             if (n++ > 10000) {
