@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -50,9 +50,9 @@ bool CommandMergeChanges::setup(const std::vector<std::string>& arguments) {
     ("simplify,s", "Simplify change")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_multiple_inputs_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_multiple_inputs_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -108,7 +108,7 @@ bool CommandMergeChanges::run() {
     // to each object to objects collection.
     m_vout << "Reading change file contents...\n";
     osmium::ProgressBar progress_bar{file_size_sum(m_input_files), display_progress()};
-    for (osmium::io::File& change_file : m_input_files) {
+    for (const osmium::io::File& change_file : m_input_files) {
         osmium::io::Reader reader{change_file, osmium::osm_entity_bits::object};
         while (osmium::memory::Buffer buffer = reader.read()) {
             progress_bar.update(reader.offset());
