@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -49,8 +49,8 @@ bool CommandQueryLocationsIndex::setup(const std::vector<std::string>& arguments
     ("dump", "Dump all locations to STDOUT")
     ;
 
-    po::options_description opts_common{add_common_options(false)};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options(false)};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
@@ -101,7 +101,7 @@ bool CommandQueryLocationsIndex::setup(const std::vector<std::string>& arguments
         }
         const auto id = vm["node-id"].as<std::string>();
         const auto r = osmium::string_to_object_id(id.c_str(), osmium::osm_entity_bits::node, osmium::item_type::node);
-        m_id = static_cast<osmium::unsigned_object_id_type>(r.second);
+        m_id = r.second;
     } else if (!m_dump) {
         throw argument_error{"Missing node ID on command line."};
     }
@@ -121,7 +121,7 @@ bool CommandQueryLocationsIndex::run() {
         throw std::system_error{errno, std::system_category(), std::string("Can not open index file '") + m_index_file_name + "'"};
     }
 
-    osmium::index::map::DenseFileArray<osmium::unsigned_object_id_type, osmium::Location> location_index{fd};
+    const osmium::index::map::DenseFileArray<osmium::unsigned_object_id_type, osmium::Location> location_index{fd};
 
     if (m_dump) {
         const std::size_t max_buffer_size = 11UL * 1024UL * 1024UL;
