@@ -2,7 +2,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -74,15 +74,15 @@ osmium::object_id_type id_map::operator()(osmium::object_id_type id) {
     // New ID is larger than all existing IDs. Add it to end and return.
     if (m_ids.empty() || osmium::id_order{}(m_ids.back(), id)) {
         m_ids.push_back(id);
-        return add_offset_to_id(m_ids.size());
+        return add_offset_to_id(static_cast<osmium::object_id_type>(m_ids.size()));
     }
 
     const auto element = std::lower_bound(m_ids.cbegin(), m_ids.cend(), id, osmium::id_order{});
     // Old ID not found in m_ids, add to m_extra_ids.
     if (element == m_ids.cend() || *element != id) {
         m_ids.push_back(m_ids.back());
-        m_extra_ids[id] = m_ids.size();
-        return add_offset_to_id(m_ids.size());
+        m_extra_ids[id] = static_cast<osmium::object_id_type>(m_ids.size());
+        return add_offset_to_id(static_cast<osmium::object_id_type>(m_ids.size()));
     }
 
     // Old ID found in m_ids, return.
@@ -119,16 +119,16 @@ void id_map::print(osmium::object_id_type new_id) {
 void id_map::read(int fd, std::size_t file_size) {
     const auto num_elements = file_size / sizeof(osmium::object_id_type);
     m_ids.reserve(num_elements);
-    osmium::TypedMemoryMapping<osmium::object_id_type> mapping{num_elements, osmium::MemoryMapping::mapping_mode::readonly, fd};
+    const osmium::TypedMemoryMapping<osmium::object_id_type> mapping{num_elements, osmium::MemoryMapping::mapping_mode::readonly, fd};
 
     osmium::object_id_type last_id = 0;
-    for (osmium::object_id_type id : mapping) {
+    for (const osmium::object_id_type id : mapping) {
         if (osmium::id_order{}(last_id, id)) {
             m_ids.push_back(id);
             last_id = id;
         } else {
             m_ids.push_back(last_id);
-            m_extra_ids[id] = m_ids.size();
+            m_extra_ids[id] = static_cast<osmium::object_id_type>(m_ids.size());
         }
     }
 }
@@ -184,9 +184,9 @@ bool CommandRenumber::setup(const std::vector<std::string>& arguments) {
     ("start-id,s", po::value<std::string>(), "Comma separated list of first node, way, and relation id to use (default: 1,1,1)")
     ;
 
-    po::options_description opts_common{add_common_options()};
-    po::options_description opts_input{add_single_input_options()};
-    po::options_description opts_output{add_output_options()};
+    const po::options_description opts_common{add_common_options()};
+    const po::options_description opts_input{add_single_input_options()};
+    const po::options_description opts_output{add_output_options()};
 
     po::options_description hidden;
     hidden.add_options()
