@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ class CommandTagsFilter : public CommandWithSingleOSMInput, public with_osm_outp
     bool matches_relation(const osmium::Relation& relation) const noexcept;
     bool matches_object(const osmium::OSMObject& object) const noexcept;
 
-    void mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id);
+    void mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::unsigned_object_id_type parent_id);
     bool find_relations_in_relations();
     void find_nodes_and_ways_in_relations();
     void find_nodes_in_ways();
