@@ -28,98 +28,98 @@
 
 void register_commands(CommandFactory& cmd_factory) {
     cmd_factory.register_command("add-locations-to-ways", "Add node locations to ways", [&]() {
-        return new CommandAddLocationsToWays{cmd_factory};
+        return std::make_unique<CommandAddLocationsToWays>(cmd_factory);
     });
 
     cmd_factory.register_command("apply-changes", "Apply OSM change files to OSM data file", [&]() {
-        return new CommandApplyChanges{cmd_factory};
+        return std::make_unique<CommandApplyChanges>(cmd_factory);
     });
 
     cmd_factory.register_command("cat", "Concatenate OSM files and convert to different formats", [&]() {
-        return new CommandCat{cmd_factory};
+        return std::make_unique<CommandCat>(cmd_factory);
     });
 
     cmd_factory.register_command("changeset-filter", "Filter OSM changesets by different criteria", [&]() {
-        return new CommandChangesetFilter{cmd_factory};
+        return std::make_unique<CommandChangesetFilter>(cmd_factory);
     });
 
     cmd_factory.register_command("check-refs", "Check referential integrity of an OSM file", [&]() {
-        return new CommandCheckRefs{cmd_factory};
+        return std::make_unique<CommandCheckRefs>(cmd_factory);
     });
 
     cmd_factory.register_command("create-locations-index", "Create node locations index on disk", [&]() {
-        return new CommandCreateLocationsIndex{cmd_factory};
+        return std::make_unique<CommandCreateLocationsIndex>(cmd_factory);
     });
 
     cmd_factory.register_command("derive-changes", "Create OSM change files from two OSM data files", [&]() {
-        return new CommandDeriveChanges{cmd_factory};
+        return std::make_unique<CommandDeriveChanges>(cmd_factory);
     });
 
     cmd_factory.register_command("diff", "Display differences between OSM files", [&]() {
-        return new CommandDiff{cmd_factory};
+        return std::make_unique<CommandDiff>(cmd_factory);
     });
 
     cmd_factory.register_command("export", "Export OSM data", [&]() {
-        return new CommandExport{cmd_factory};
+        return std::make_unique<CommandExport>(cmd_factory);
     });
 
     cmd_factory.register_command("extract", "Create geographic extract", [&]() {
-        return new CommandExtract{cmd_factory};
+        return std::make_unique<CommandExtract>(cmd_factory);
     });
 
     cmd_factory.register_command("fileinfo", "Show information about OSM file", [&]() {
-        return new CommandFileinfo{cmd_factory};
+        return std::make_unique<CommandFileinfo>(cmd_factory);
     });
 
     cmd_factory.register_command("getid", "Get objects with given ID from OSM file", [&]() {
-        return new CommandGetId{cmd_factory};
+        return std::make_unique<CommandGetId>(cmd_factory);
     });
 
     cmd_factory.register_command("getparents", "Get parents of objects from OSM file", [&]() {
-        return new CommandGetParents{cmd_factory};
+        return std::make_unique<CommandGetParents>(cmd_factory);
     });
 
     cmd_factory.register_command("help", "Show osmium help", [&]() {
-        return new CommandHelp{cmd_factory};
+        return std::make_unique<CommandHelp>(cmd_factory);
     });
 
     cmd_factory.register_command("merge-changes", "Merge several OSM change files into one", [&]() {
-        return new CommandMergeChanges{cmd_factory};
+        return std::make_unique<CommandMergeChanges>(cmd_factory);
     });
     cmd_factory.register_command("merge", "Merge several sorted OSM files into one", [&]() {
-        return new CommandMerge{cmd_factory};
+        return std::make_unique<CommandMerge>(cmd_factory);
     });
 
     cmd_factory.register_command("query-locations-index", "Query node locations index on disk", [&]() {
-        return new CommandQueryLocationsIndex{cmd_factory};
+        return std::make_unique<CommandQueryLocationsIndex>(cmd_factory);
     });
 
     cmd_factory.register_command("removeid", "Remove objects from OSM file by ID", [&]() {
-        return new CommandRemoveId{cmd_factory};
+        return std::make_unique<CommandRemoveId>(cmd_factory);
     });
 
     cmd_factory.register_command("renumber", "Renumber IDs in OSM file", [&]() {
-        return new CommandRenumber{cmd_factory};
+        return std::make_unique<CommandRenumber>(cmd_factory);
     });
 
     cmd_factory.register_command("show", "Show OSM file contents", [&]() {
-        return new CommandShow{cmd_factory};
+        return std::make_unique<CommandShow>(cmd_factory);
     });
 
     cmd_factory.register_command("sort", "Sort OSM data files", [&]() {
-        return new CommandSort{cmd_factory};
+        return std::make_unique<CommandSort>(cmd_factory);
     });
 
     cmd_factory.register_command("tags-count", "Count OSM tags", [&]() {
-        return new CommandTagsCount{cmd_factory};
+        return std::make_unique<CommandTagsCount>(cmd_factory);
     });
 
     cmd_factory.register_command("tags-filter", "Filter OSM data based on tags", [&]() {
-        return new CommandTagsFilter{cmd_factory};
+        return std::make_unique<CommandTagsFilter>(cmd_factory);
     });
 
     cmd_factory.register_command("time-filter", "Filter OSM data from a point in time or a time span out of a history file", [&]() {
-        return new CommandTimeFilter{cmd_factory};
+        return std::make_unique<CommandTimeFilter>(cmd_factory);
     });
 }
 
