@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ ExtractPolygon::ExtractPolygon(const osmium::io::File& output_file, const std::s
         num_bands = max_bands;
     }
 
-    m_bands.resize(num_bands);
+    m_bands.resize(num_bands + 1);
 
     m_dy = (y_max() - y_min()) / num_bands;
 
@@ -87,9 +87,10 @@ ExtractPolygon::ExtractPolygon(const osmium::io::File& output_file, const std::s
     for (const auto& segment : segments) {
         const std::pair<int32_t, int32_t> mm = std::minmax(segment.first().y(), segment.second().y());
         const uint32_t band_min = (mm.first - y_min()) / m_dy;
-        const uint32_t band_max = std::min(num_bands, ((mm.second - y_min()) / m_dy) + 1);
+        const uint32_t band_max = (mm.second - y_min()) / m_dy;
+        assert(band_min < m_bands.size() && band_max < m_bands.size());
 
-        for (auto band = band_min; band < band_max; ++band) {
+        for (auto band = band_min; band <= band_max; ++band) {
             m_bands[band].push_back(segment);
         }
     }
@@ -123,10 +124,8 @@ bool ExtractPolygon::contains(const osmium::Location& location) const noexcept {
         return false;
     }
 
-    std::size_t band = (location.y() - y_min()) / m_dy;
-    if (band >= m_bands.size()) {
-        band = m_bands.size() - 1;
-    }
+    const std::size_t band = (location.y() - y_min()) / m_dy;
+    assert(band < m_bands.size());
 
     bool inside = false;
 
@@ -135,10 +134,10 @@ bool ExtractPolygon::contains(const osmium::Location& location) const noexcept {
             return true;
         }
         if ((segment.second().y() > location.y()) != (segment.first().y() > location.y())) {
-            const int64_t ax = int64_t(segment.first().x()) - int64_t(segment.second().x());
-            const int64_t ay = int64_t(segment.first().y()) - int64_t(segment.second().y());
-            const int64_t tx = int64_t(location.x())        - int64_t(segment.second().x());
-            const int64_t ty = int64_t(location.y())        - int64_t(segment.second().y());
+            const auto ax = static_cast<int64_t>(segment.first().x()) - static_cast<int64_t>(segment.second().x());
+            const auto ay = static_cast<int64_t>(segment.first().y()) - static_cast<int64_t>(segment.second().y());
+            const auto tx = static_cast<int64_t>(location.x())        - static_cast<int64_t>(segment.second().x());
+            const auto ty = static_cast<int64_t>(location.y())        - static_cast<int64_t>(segment.second().y());
 
             const bool comp = tx * ay < ax * ty;
 
