@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -45,9 +45,9 @@ OSMFileParser::OSMFileParser(osmium::memory::Buffer& buffer, std::string file_na
 }
 
 std::size_t OSMFileParser::operator()() {
-    osmium::io::File input_file{m_file_name};
+    const osmium::io::File input_file{m_file_name};
 
-    osmium::area::Assembler::config_type assembler_config;
+    const osmium::area::Assembler::config_type assembler_config;
     osmium::area::MultipolygonCollector<osmium::area::Assembler> collector{assembler_config};
 
     {
