@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2022  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2023  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 namespace strategy_complete_ways {
 
     void Data::add_relation_parents(osmium::unsigned_object_id_type id, const osmium::index::RelationsMapIndex& map) {
-        map.for_each_parent(id, [&](osmium::unsigned_object_id_type parent_id) {
+        map.for_each(id, [&](osmium::unsigned_object_id_type parent_id) {
             if (!relation_ids.get(parent_id)) {
                 relation_ids.set(parent_id);
                 add_relation_parents(parent_id, map);
@@ -175,7 +175,7 @@ namespace strategy_complete_ways {
             // recursively get parents of all relations that are in an extract
             const auto relations_map = pass1.relations_map_stash().build_member_to_parent_index();
             for (auto& e : m_extracts) {
-                for (osmium::unsigned_object_id_type id : e.relation_ids) {
+                for (const osmium::unsigned_object_id_type id : e.relation_ids) {
                     e.add_relation_parents(id, relations_map);
                 }
             }
